import { Component, inject } from '@angular/core';
import { NonNullableFormBuilder, Validators } from '@angular/forms';
import { NZ_MODAL_DATA } from 'ng-zorro-antd/modal';
import { CommonNzModule } from '../../../../../common.nz.module';
import { BasicDataService } from '../../../../../services/basic.service';

export interface EquipmentFormModalData {
  keyWord: string;
  type: 'add' | 'edit';
  params: {
    id?: number;
    name?: string;
    line?: string;
    unit?: string;
  };
  lines: BasicData.Predefine[];
}

@Component({
  selector: 'equipment-form',
  standalone: true,
  imports: [CommonNzModule],
  templateUrl: './form.component.html',
  styleUrl: './form.component.less',
})
export class EquipmentFormComponent {
  readonly nzModalData: EquipmentFormModalData = inject(NZ_MODAL_DATA);
  validateForm = this.fb.group({
    name: this.fb.control<string>('', [Validators.required]),
    id: this.fb.control<number>(0),
    line: this.fb.control<string>('', [Validators.required]),
    unit: this.fb.control<string>('', [Validators.required]),
  });
  loading = false;
  constructor(
    private fb: NonNullableFormBuilder,
    private basic: BasicDataService
  ) {}
  ngOnInit() {
    this.init();
    this.basic.fetchBasicData();
  }
  async init() {
    if (this.nzModalData.type === 'edit') {
      const { name, id, line, unit } = this.nzModalData.params;
      this.validateForm.patchValue({
        name,
        id,
        line,
        unit,
      });
    }
  }
  async submit() {
    if (this.loading) return;
    if (!this.validateForm.valid) {
      Object.values(this.validateForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
      return Promise.reject();
    }
    this.loading = true;
    const values = this.validateForm.value;
    return Promise.resolve({
      name: values.name!,
      id: values.id,
      line: values.line,
      unit: values.unit,
    });
  }
  get lineList() {
    return this.nzModalData.lines || [];
  }
  get unitList() {
    const line = this.validateForm.value.line;
    if (!line) return [];
    return this.basic.units?.filter(item => item.line === line) || [];
  }
}
