import { Component, inject } from '@angular/core';
import { NonNullableFormBuilder, Validators } from '@angular/forms';
import { NZ_MODAL_DATA } from 'ng-zorro-antd/modal';
import { CommonNzModule } from '../../../../../common.nz.module';
import { BasicDataService } from '../../../../../services/basic.service';

export interface UnitFormModalData {
  keyWord: string;
  type: 'add' | 'edit';
  params: {
    id?: number;
    name?: string;
    line?: string;
    type?: string;
  };
  lines: BasicData.Predefine[];
}

@Component({
  selector: 'unit-form',
  standalone: true,
  imports: [CommonNzModule],
  templateUrl: './form.component.html',
  styleUrl: './form.component.less',
})
export class UnitFormComponent {
  readonly nzModalData: UnitFormModalData = inject(NZ_MODAL_DATA);
  validateForm = this.fb.group({
    name: this.fb.control<string>('', [Validators.required]),
    id: this.fb.control<number>(0),
    line: this.fb.control<string>('', [Validators.required]),
    type: this.fb.control<string>('', [Validators.required]),
  });
  loading = false;
  constructor(
    private fb: NonNullableFormBuilder,
    private basic: BasicDataService
  ) {}
  ngOnInit() {
    this.init();
    this.basic.fetchBasicData();
  }
  async init() {
    if (this.nzModalData.type === 'edit') {
      const { name, id, line, type } = this.nzModalData.params;
      this.validateForm.patchValue({
        name,
        id,
        line,
        type,
      });
    }
  }
  async submit() {
    if (this.loading) return;
    if (!this.validateForm.valid) {
      Object.values(this.validateForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
      return Promise.reject();
    }
    this.loading = true;
    const values = this.validateForm.value;
    return Promise.resolve({
      name: values.name!,
      id: values.id,
      line: values.line,
      type: values.type,
    });
  }
  get lineList() {
    return this.nzModalData.lines || [];
  }
  get typeList() {
    return this.basic.types || [];
  }
}
