import { Component } from '@angular/core';
import { CommonNzModule } from '../../../../common.nz.module';
import { Column, SimpleFormPageComponent } from '../../../../shared/simple-form-page/simple-form-page.component';
import { UnitFormComponent, UnitFormModalData } from './form/form.component';

@Component({
  selector: 'app-unit',
  standalone: true,
  imports: [CommonNzModule],
  templateUrl: './unit.component.html',
  styleUrl: './unit.component.less',
})
export class UnitComponent extends SimpleFormPageComponent<BasicData.Unit> {
  filterList: BasicData.Unit[] = [];
  override keyWord: string = '生产单元';
  override key: string = 'name';
  override columns: Column[] = [
    {
      key: 'id',
      label: '编号',
      // sortOrder: 'ascend',
      // sortable: true,
      width: '80px',
    },
    { key: 'name', label: '生产单元' },
    { key: 'line', label: '线路' },
    { key: 'type', label: '生产类型' },
  ];
  override inputFields = [{ label: '生产单元', key: 'unit', initValue: '' }];
  override validateForm = this.fb.group({
    unit: this.fb.control<string | undefined>(undefined),
    line: this.fb.control<string | undefined>(undefined),
    type: this.fb.control<string | undefined>(undefined),
  });
  override ngOnInit(): void {
    super.ngOnInit();
  }
  override async fetchList() {
    const list = (await this.api.basic.getUnitList()).filter(item => this.lines.map(l => l.value).includes(item.line));
    this.list = list;
    this.resetFilterList();
  }
  override async onEdit(data: Partial<BasicData.Unit>) {
    return this.api.basic.updateUnit(data).then(() => {
      this.message.success('编辑成功');
    });
  }
  override async onAdd(data: Partial<BasicData.Unit>) {
    return this.api.basic.addUnit(data).then(() => {
      this.message.success('新增成功');
    });
  }
  override async onDelete(data: BasicData.Unit): Promise<void> {
    return this.api.basic.deletedUnit(data.id).then(() => {
      this.message.success('删除成功');
    });
  }
  override createModal(type: 'add' | 'edit', data?: BasicData.Unit): void {
    const name = data ? this.getValue(data, this.key) : '';
    this.modal.create<UnitFormComponent, UnitFormModalData>({
      nzClassName: 'precaution-modal',
      nzTitle: type === 'add' ? '新增' + this.keyWord : '编辑' + this.keyWord + ' - ' + name,
      nzOkText: type === 'add' ? '新增' : '修改',
      nzContent: UnitFormComponent,
      nzWidth: 500,
      nzViewContainerRef: this.viewContainerRef,
      nzData: {
        keyWord: this.keyWord,
        type,
        params: {
          name,
          id: data ? this.getValue(data, 'id') : undefined,
          line: data ? this.getValue(data, 'line') : undefined,
          type: data ? this.getValue(data, 'type') : undefined,
        },
        lines: this.lines,
      },
      nzOnOk: async instance => {
        const res = await instance.submit();
        if (type === 'add') {
          await this.onAdd(res!);
          this.fetchList();
        } else {
          await this.onEdit({
            ...data!,
            ...res!,
          });
          this.onSearch();
        }
      },
    });
  }
  searchFormChange() {
    this.resetFilterList();
  }
  resetFilterList() {
    const { unit, line, type } = this.validateForm.value;
    this.filterList = this.list.filter(item => {
      let isMatch = true;
      if (unit) {
        isMatch = item.name.includes(unit);
      }
      if (isMatch && line) {
        isMatch = item.line === line;
      }
      if (isMatch && type) {
        isMatch = item.type === type;
      }
      return isMatch;
    });
  }
  get lines() {
    return this.basic.lines || [];
  }
  get types() {
    return this.basic.types || [];
  }
}
