import { Component, TemplateRef, ViewChild, ViewContainerRef } from '@angular/core';
import { NzModalService } from 'ng-zorro-antd/modal';
import { CommonNzModule } from '../../../../../common.nz.module';
import { DetailComponent } from './detail/detail.component';

interface RecordItem {
  // 序号
  id: number;
  // 企业名称
  enterpriseName: string;
  // 更新风险类别
  updateRiskCategory: string;
  // 更新原因
  updateReason: string;
  // 上传人
  uploader: string;
  // 更新日期
  updateDate: string;
}

const getMockItem = (id: number): RecordItem => ({
  id,
  enterpriseName: `企业名称${id}`,
  updateRiskCategory: `XXXXX风险项`,
  updateReason: `XXXXX更新原因`,
  uploader: `阿松大`,
  updateDate: `2024/01/01 12:00`,
});

@Component({
  selector: 'risk-update-record',
  standalone: true,
  imports: [CommonNzModule, DetailComponent],
  templateUrl: './update-record.component.html',
  styleUrl: './update-record.component.less',
})
export class UpdateRecordComponent {
  @ViewChild('detailTpl') detailTpl!: TemplateRef<void>;
  pageConfig: IPageConfig = {
    page: 0,
    total: 0,
    size: 10,
  };
  constructor(
    private viewContainerRef: ViewContainerRef,
    private modal: NzModalService
  ) {}
  onCurrentPageChange(page: number) {
    this.pageConfig.page = page;
  }

  list: RecordItem[] = Array.from({ length: 10 }, (_, index) => getMockItem(index + 1));

  showDetail(data: RecordItem) {
    console.log(data);
    this.modal.create<TemplateRef<void>, {}>({
      nzContent: this.detailTpl,
      nzViewContainerRef: this.viewContainerRef,
      nzClassName: 'noop-modal',
      nzClosable: true,
      // nzCloseIcon: this.closeIcon,
      nzData: {
        id: null,
        data,
      },
      nzWidth: 'calc(100vw - 344px)',
      nzFooter: null,
    });
  }
}
