import { Component, ViewContainerRef } from '@angular/core';
import { NzModalService } from 'ng-zorro-antd/modal';
import { CommonNzModule } from '../../../../common.nz.module';
import { ApiService } from '../../../../services/api.service';
import { FilterButtonGroupComponent } from '../../../../shared/filter-button-group/filter-button-group.component';
import { DocImportComponent, DocImportModalData } from './doc-import/doc-import.component';
import { DocTableComponent } from './doc-table/doc-table.component';

const getMockItem = (id: number): Knowledge.Doc => ({
  id,
  name: `文档${id}`,
  department: `部门${id}`,
  updateDate: '2024/9/9',
});

@Component({
  selector: 'knowledge-doc',
  standalone: true,
  imports: [CommonNzModule, FilterButtonGroupComponent, DocTableComponent],
  templateUrl: './doc.component.html',
  styleUrl: './doc.component.less',
})
export class DocComponent {
  docCategories = [
    { label: '管理规定', value: 1 },
    { label: '规程', value: 2 },
    { label: '作业指导', value: 3 },
    { label: '应急预案', value: 4 },
    { label: '教育培训', value: 5 },
  ];
  levelOptions = [
    { label: '集团级', value: 1 },
    { label: '公司级', value: 2 },
  ];
  category = this.docCategories[0].value;
  level = this.levelOptions[0].value;

  pageConfig: IPageConfig = {
    page: 0,
    total: 0,
    size: 10,
  };
  list: Knowledge.Doc[] = Array.from({ length: 10 }, (_, index) => getMockItem(index + 1));

  constructor(
    private modal: NzModalService,
    private viewContainerRef: ViewContainerRef,
    private api: ApiService
  ) {}

  ngOnInit() {
    this.fetchList();
  }

  changeCategory(value: number | string) {
    this.category = value as number;
    this.fetchList();
  }
  changeLevel(value: number | string) {
    this.level = value as number;
    this.fetchList();
  }

  onPageChange(page: number) {
    this.pageConfig.page = page;
    this.fetchList();
  }

  onImport() {
    this.modal.create<DocImportComponent, DocImportModalData>({
      nzClassName: 'precaution-modal',
      nzTitle: '文档 - 导入',
      nzContent: DocImportComponent,
      nzWidth: 500,
      nzBodyStyle: { paddingBottom: '0px' },
      nzViewContainerRef: this.viewContainerRef,
      nzData: {
        categories: this.docCategories,
        levels: this.levelOptions,
        category: this.category,
        level: this.level,
        onImportSuccess: () => {
          this.onSearch();
        },
      },
      nzFooter: null,
    });
  }

  onSearch() {
    console.log('search');
    this.fetchList();
  }
  async fetchList() {
    const result = await this.api.knowledge.getDocList({
      category: this.category,
      level: this.level,
    });
    console.log(result);
  }
}
