import { Injectable } from '@angular/core';
import { Subject } from 'rxjs';
import { ApiService } from './api.service';

@Injectable({
  providedIn: 'root',
})
export class BasicDataService {
  lines: BasicData.Predefine[] = [];
  types: BasicData.Predefine[] = [];
  jobs: BasicData.Predefine[] = [];
  units: BasicData.Unit[] = [];
  private _initialized = false;
  $fetched = new Subject<void>();
  constructor(private readonly api: ApiService) {}
  async fetchBasicData() {
    return Promise.all([this.fetchLines(), this.fetchTypes(), this.fetchJobs(), this.fetchUnits()]).then(() => {
      setTimeout(() => {
        this.$fetched.next();
      }, 100);
    });
  }
  async fetchUnits() {
    this.units = await this.api.basic.getUnitList();
  }
  async fetchLines() {
    this.lines = await this.api.basic.getPredefineList('line');
  }
  async fetchTypes() {
    this.types = await this.api.basic.getPredefineList('product');
  }
  async fetchJobs() {
    this.jobs = await this.api.basic.getPredefineList('job');
  }
  clear() {
    this._initialized = false;
    this.lines = [];
    this.types = [];
    this.jobs = [];
    this.units = [];
  }

  async init(): Promise<boolean> {
    if (this._initialized) {
      return true;
    }
    return this.onInit().catch(err => {
      console.error('init error', err);
      return false;
    });
  }

  private async onInit() {
    await this.fetchBasicData();
    this._initialized = true;
    return true;
  }
}
